==> pygame-engine-0.0.3.tar.gz: pygame-engine-0.0.3/README.md <==
# Engine

Engine is a simple game engine made using [Pygame](https://www.pygame.org/).  
One of the purposes of this engine is for making easier the use of Pygame to build more complex games.  
This engine includes support for collisions, meshes, materials, game objects and scenes.  
The elements used are very similar to the ones used in the engine [Unity](https://unity3d.com/ "Unity Official Website").

## Getting Started

These instructions will get you a copy of the project up and running on your local machine if you use Linux. 
Instructions for Windows and Mac are similar.

### Prerequisites

You will just have to install Pygame. The instructions below will show you how to do this for Linux (Ubuntu 16.04).

First, install Python3 setup tools and pip:

```
$ sudo apt-get install python3-setuptools
$ sudo easy_install3 pip
```

Then install Pygame using pip:

```
$ sudo pip3.5 install pygame
```

## Notes about documentation and contributing

If any substantial change is made, please, help out with the documentation using the [wiki](https://github.com/CarlosMatheus/Balance/wiki).

## About

This project aims to create a game engine to make easier the precess of game development using Pygame. Therefore, the main frame of the game is flexible and can be adapted to multiple types of games.
To understand a little bit more about how the code is structured visit the [wiki](https://github.com/CarlosMatheus/Engine/wiki).

## Authors

* **Carlos Matheus Barros da Silva** - [CarlosMatheus](https://github.com/CarlosMatheus)
* **Aloysio Galvão Lopes** - [aloysiogl](https://github.com/aloysiogl)
* **Igor Albuquerque Silva** - [igoralbuq](https://github.com/igoralbuq)
* **Eric Pereira Queiroz Moreira** - [ericpqmor](https://github.com/ericpqmor)
* **Igor Mourão Ribeiro** - [igor-ribeiiro](https://github.com/igor-ribeiiro)

## License

This project is licensed under the MIT License - see the [licence](LICENCE.md) file for details.

## Acknowledgments

* **Professor Edgar Toshiro Yano** - [Curriculum](http://buscatextual.cnpq.br/buscatextual/visualizacv.do?id=K4798593T1&idiomaExibicao=2)

==> pygame-engine-0.0.5.tar.gz: pygame-engine-0.0.5/README.md <==
# Pygin

Pygin is a simple game engine made using [Pygame](https://www.pygame.org/).  
One of the purposes of this engine is for making to build more complex games using python.  
This engine includes support for collisions, meshes, materials, game objects and scenes.  
The elements used are very similar to the ones used in the engine [Unity](https://unity3d.com/ "Unity Official Website").

## Getting Started

### Install Python

Install de most recent Python version and the most recent version of pip.

### Install Pygin

You will just have to install the Pygin packge.

```
$ pip install pygin
```

## Notes about documentation and contributing

If any substantial change is made, please, help out with the documentation using the [wiki](https://github.com/CarlosMatheus/Balance/wiki).

## About

This project aims to create a game engine to make easier the precess of game development using python.
To understand a little bit more about how the code is structured visit the [wiki](https://github.com/CarlosMatheus/Engine/wiki).

## Example Games

![game](https://media.giphy.com/media/xB2Y7NHFE8C2Ip9EHD/giphy.gif)
![game](https://media.giphy.com/media/cdyniVu3x1ydtoq99k/giphy.gif)

Check out the game [Balance](https://github.com/CarlosMatheus/Balance), a simple and challenging arcade game made using Pygin.

## Authors

* **Carlos Matheus Barros da Silva** - [CarlosMatheus](https://github.com/CarlosMatheus)
* **Aloysio Galvão Lopes** - [aloysiogl](https://github.com/aloysiogl)
* **Igor Albuquerque Silva** - [igoralbuq](https://github.com/igoralbuq)
* **Eric Pereira Queiroz Moreira** - [ericpqmor](https://github.com/ericpqmor)
* **Igor Mourão Ribeiro** - [igor-ribeiiro](https://github.com/igor-ribeiiro)

## License

This project is licensed under the MIT License - see the [licence](LICENCE.md) file for details.

## Acknowledgments

* **Professor Edgar Toshiro Yano** - [Curriculum](http://buscatextual.cnpq.br/buscatextual/visualizacv.do?id=K4798593T1&idiomaExibicao=2)
